#!/bin/bash
# packager         : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location  : http://flac.sourceforge.net/index.html
# last revised     : 14/10/07

softname='flac'
softversion='1.2.1'
packageversion='50.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# put slack-desc in place
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: Free Lossless Audio Codec
$softname:
$softname: FLAC stands for Free Lossless Audio Codec. Grossly
$softname: oversimplified. FLAC is similar to MP3, but lossless and free.
$softname: 
$softname:
$softname:
$softname:
$softname: 
$softname:
$softname: 
EOF

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src

# build

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --enable-static=no \
      --with-ogg=/usr/lib \
      --disable-doxygen-docs \
      --disable-xmms-plugin \

    make
    make install DESTDIR=$dest
    
# add 'defaults' files
cp -a \
      AUTHORS COPYING* README doc/FLAC.tag \
      $dest/usr/doc/$softname-$softversion

# remove HTML and API doc
rm -rf $dest/usr/share/doc
cat << EOF > $dest/usr/doc/$softname-$softversion/API_HTML_doc.README
Full HTML based API and general documentation can be found in the FLAC
source package or online.
EOF

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# put the ZenWalk build in the right directory
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
